# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .app_cookie_stickiness_policy import *
from .attachment import *
from .get_hosted_zone_id import *
from .get_load_balancer import *
from .get_service_account import *
from .listener_policy import *
from .load_balancer import *
from .load_balancer_backend_server_policy import *
from .load_balancer_cookie_stickiness_policy import *
from .load_balancer_policy import *
from .ssl_negotiation_policy import *
from ._inputs import *
from . import outputs

def _register_module():
    import pulumi
    from .. import _utilities


    class Module(pulumi.runtime.ResourceModule):
        _version = _utilities.get_semver_version()

        def version(self):
            return Module._version

        def construct(self, name: str, typ: str, urn: str) -> pulumi.Resource:
            if typ == "aws:elasticloadbalancing/appCookieStickinessPolicy:AppCookieStickinessPolicy":
                return AppCookieStickinessPolicy(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:elasticloadbalancing/attachment:Attachment":
                return Attachment(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:elasticloadbalancing/listenerPolicy:ListenerPolicy":
                return ListenerPolicy(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:elasticloadbalancing/loadBalancer:LoadBalancer":
                return LoadBalancer(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:elasticloadbalancing/loadBalancerBackendServerPolicy:LoadBalancerBackendServerPolicy":
                return LoadBalancerBackendServerPolicy(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:elasticloadbalancing/loadBalancerCookieStickinessPolicy:LoadBalancerCookieStickinessPolicy":
                return LoadBalancerCookieStickinessPolicy(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:elasticloadbalancing/loadBalancerPolicy:LoadBalancerPolicy":
                return LoadBalancerPolicy(name, pulumi.ResourceOptions(urn=urn))
            elif typ == "aws:elasticloadbalancing/sslNegotiationPolicy:SslNegotiationPolicy":
                return SslNegotiationPolicy(name, pulumi.ResourceOptions(urn=urn))
            else:
                raise Exception(f"unknown resource type {typ}")


    _module_instance = Module()
    pulumi.runtime.register_resource_module("aws", "elasticloadbalancing/appCookieStickinessPolicy", _module_instance)
    pulumi.runtime.register_resource_module("aws", "elasticloadbalancing/attachment", _module_instance)
    pulumi.runtime.register_resource_module("aws", "elasticloadbalancing/listenerPolicy", _module_instance)
    pulumi.runtime.register_resource_module("aws", "elasticloadbalancing/loadBalancer", _module_instance)
    pulumi.runtime.register_resource_module("aws", "elasticloadbalancing/loadBalancerBackendServerPolicy", _module_instance)
    pulumi.runtime.register_resource_module("aws", "elasticloadbalancing/loadBalancerCookieStickinessPolicy", _module_instance)
    pulumi.runtime.register_resource_module("aws", "elasticloadbalancing/loadBalancerPolicy", _module_instance)
    pulumi.runtime.register_resource_module("aws", "elasticloadbalancing/sslNegotiationPolicy", _module_instance)

_register_module()
